==> peony-debug-3.2.3-2-x86_64.pkg.tar.zst: usr/src/debug/peony/peony-3.2.3/peony-qt-desktop/qrc_peony-qt-desktop-style.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.10
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/peony/src/peony-3.2.3/peony-qt-desktop/desktop-icon-view.qss
  0x0,0x0,0x1,0x4e,
  0x50,
  0x65,0x6f,0x6e,0x79,0x2d,0x2d,0x44,0x65,0x73,0x6b,0x74,0x6f,0x70,0x49,0x63,0x6f,
  0x6e,0x56,0x69,0x65,0x77,0xa,0x7b,0xa,0x20,0x20,0x20,0x20,0x62,0x61,0x63,0x6b,
  0x67,0x72,0x6f,0x75,0x6e,0x64,0x2d,0x63,0x6f,0x6c,0x6f,0x72,0x3a,0x20,0x74,0x72,
  0x61,0x6e,0x73,0x70,0x61,0x72,0x65,0x6e,0x74,0x3b,0xa,0x20,0x20,0x20,0x20,0x62,
  0x6f,0x72,0x64,0x65,0x72,0x3a,0x20,0x30,0x70,0x78,0x3b,0xa,0x20,0x20,0x20,0x20,
  0x70,0x61,0x64,0x64,0x69,0x6e,0x67,0x3a,0x20,0x30,0x70,0x78,0x3b,0xa,0x7d,0xa,
  0xa,0x50,0x65,0x6f,0x6e,0x79,0x2d,0x2d,0x44,0x65,0x73,0x6b,0x74,0x6f,0x70,0x49,
  0x63,0x6f,0x6e,0x56,0x69,0x65,0x77,0x3a,0x3a,0x49,0x74,0x65,0x6d,0xa,0x7b,0xa,
  0x20,0x20,0x20,0x20,0x70,0x61,0x64,0x64,0x69,0x6e,0x67,0x2d,0x74,0x6f,0x70,0x3a,
  0x20,0x35,0x70,0x78,0x3b,0xa,0x20,0x20,0x20,0x20,0x69,0x6d,0x61,0x67,0x65,0x2d,
  0x70,0x6f,0x73,0x69,0x74,0x69,0x6f,0x6e,0x3a,0x20,0x62,0x6f,0x74,0x74,0x6f,0x6d,
  0x3b,0xa,0x7d,0xa,0xa,0x50,0x65,0x6f,0x6e,0x79,0x2d,0x2d,0x44,0x65,0x73,0x6b,
  0x74,0x6f,0x70,0x49,0x63,0x6f,0x6e,0x56,0x69,0x65,0x77,0x3a,0x3a,0x49,0x74,0x65,
  0x6d,0x3a,0x68,0x6f,0x76,0x65,0x72,0xa,0x7b,0xa,0x20,0x20,0x20,0x20,0x62,0x61,
  0x63,0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,0x2d,0x63,0x6f,0x6c,0x6f,0x72,0x3a,0x20,
  0x74,0x72,0x61,0x6e,0x73,0x70,0x61,0x72,0x65,0x6e,0x74,0x3b,0xa,0x7d,0xa,0xa,
  0x50,0x65,0x6f,0x6e,0x79,0x2d,0x2d,0x44,0x65,0x73,0x6b,0x74,0x6f,0x70,0x49,0x63,
  0x6f,0x6e,0x56,0x69,0x65,0x77,0x3a,0x3a,0x49,0x74,0x65,0x6d,0x3a,0x73,0x65,0x6c,
  0x65,0x63,0x74,0x65,0x64,0xa,0x7b,0xa,0x20,0x20,0x20,0x20,0x62,0x61,0x63,0x6b,
  0x67,0x72,0x6f,0x75,0x6e,0x64,0x2d,0x63,0x6f,0x6c,0x6f,0x72,0x3a,0x20,0x74,0x72,
  0x61,0x6e,0x73,0x70,0x61,0x72,0x65,0x6e,0x74,0x3b,0xa,0x7d,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // desktop-icon-view.qss
  0x0,0x15,
  0x8,0x24,0xab,0x83,
  0x0,0x64,
  0x0,0x65,0x0,0x73,0x0,0x6b,0x0,0x74,0x0,0x6f,0x0,0x70,0x0,0x2d,0x0,0x69,0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x2d,0x0,0x76,0x0,0x69,0x0,0x65,0x0,0x77,
  0x0,0x2e,0x0,0x71,0x0,0x73,0x0,0x73,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x8a,0xea,0x3e,0x6b,0xd0,
  // :/desktop-icon-view.qss
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x8a,0xea,0x3e,0x6b,0xd0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_peony_qt_desktop_style)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_peony_qt_desktop_style)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_peony_qt_desktop_style)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_peony_qt_desktop_style)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_peony_qt_desktop_style)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_peony_qt_desktop_style)(); }
   } dummy;
}

==> peony-debug-3.2.3-2.1-x86_64.pkg.tar.zst: usr/src/debug/peony/peony-3.2.3/peony-qt-desktop/qrc_peony-qt-desktop-style.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.11
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /startdir/src/peony-3.2.3/peony-qt-desktop/desktop-icon-view.qss
  0x0,0x0,0x1,0x4e,
  0x50,
  0x65,0x6f,0x6e,0x79,0x2d,0x2d,0x44,0x65,0x73,0x6b,0x74,0x6f,0x70,0x49,0x63,0x6f,
  0x6e,0x56,0x69,0x65,0x77,0xa,0x7b,0xa,0x20,0x20,0x20,0x20,0x62,0x61,0x63,0x6b,
  0x67,0x72,0x6f,0x75,0x6e,0x64,0x2d,0x63,0x6f,0x6c,0x6f,0x72,0x3a,0x20,0x74,0x72,
  0x61,0x6e,0x73,0x70,0x61,0x72,0x65,0x6e,0x74,0x3b,0xa,0x20,0x20,0x20,0x20,0x62,
  0x6f,0x72,0x64,0x65,0x72,0x3a,0x20,0x30,0x70,0x78,0x3b,0xa,0x20,0x20,0x20,0x20,
  0x70,0x61,0x64,0x64,0x69,0x6e,0x67,0x3a,0x20,0x30,0x70,0x78,0x3b,0xa,0x7d,0xa,
  0xa,0x50,0x65,0x6f,0x6e,0x79,0x2d,0x2d,0x44,0x65,0x73,0x6b,0x74,0x6f,0x70,0x49,
  0x63,0x6f,0x6e,0x56,0x69,0x65,0x77,0x3a,0x3a,0x49,0x74,0x65,0x6d,0xa,0x7b,0xa,
  0x20,0x20,0x20,0x20,0x70,0x61,0x64,0x64,0x69,0x6e,0x67,0x2d,0x74,0x6f,0x70,0x3a,
  0x20,0x35,0x70,0x78,0x3b,0xa,0x20,0x20,0x20,0x20,0x69,0x6d,0x61,0x67,0x65,0x2d,
  0x70,0x6f,0x73,0x69,0x74,0x69,0x6f,0x6e,0x3a,0x20,0x62,0x6f,0x74,0x74,0x6f,0x6d,
  0x3b,0xa,0x7d,0xa,0xa,0x50,0x65,0x6f,0x6e,0x79,0x2d,0x2d,0x44,0x65,0x73,0x6b,
  0x74,0x6f,0x70,0x49,0x63,0x6f,0x6e,0x56,0x69,0x65,0x77,0x3a,0x3a,0x49,0x74,0x65,
  0x6d,0x3a,0x68,0x6f,0x76,0x65,0x72,0xa,0x7b,0xa,0x20,0x20,0x20,0x20,0x62,0x61,
  0x63,0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,0x2d,0x63,0x6f,0x6c,0x6f,0x72,0x3a,0x20,
  0x74,0x72,0x61,0x6e,0x73,0x70,0x61,0x72,0x65,0x6e,0x74,0x3b,0xa,0x7d,0xa,0xa,
  0x50,0x65,0x6f,0x6e,0x79,0x2d,0x2d,0x44,0x65,0x73,0x6b,0x74,0x6f,0x70,0x49,0x63,
  0x6f,0x6e,0x56,0x69,0x65,0x77,0x3a,0x3a,0x49,0x74,0x65,0x6d,0x3a,0x73,0x65,0x6c,
  0x65,0x63,0x74,0x65,0x64,0xa,0x7b,0xa,0x20,0x20,0x20,0x20,0x62,0x61,0x63,0x6b,
  0x67,0x72,0x6f,0x75,0x6e,0x64,0x2d,0x63,0x6f,0x6c,0x6f,0x72,0x3a,0x20,0x74,0x72,
  0x61,0x6e,0x73,0x70,0x61,0x72,0x65,0x6e,0x74,0x3b,0xa,0x7d,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // desktop-icon-view.qss
  0x0,0x15,
  0x8,0x24,0xab,0x83,
  0x0,0x64,
  0x0,0x65,0x0,0x73,0x0,0x6b,0x0,0x74,0x0,0x6f,0x0,0x70,0x0,0x2d,0x0,0x69,0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x2d,0x0,0x76,0x0,0x69,0x0,0x65,0x0,0x77,
  0x0,0x2e,0x0,0x71,0x0,0x73,0x0,0x73,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x8c,0x18,0x7f,0x40,0x90,
  // :/desktop-icon-view.qss
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x8c,0x18,0x7f,0x40,0x90,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_peony_qt_desktop_style)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_peony_qt_desktop_style)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_peony_qt_desktop_style)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_peony_qt_desktop_style)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_peony_qt_desktop_style)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_peony_qt_desktop_style)(); }
   } dummy;
}
